@@ -25,10 +25,13 @@ def main (args):
     import locale
     import sys
 
+    import pygtk; pygtk.require('2.0');
+    
     import gtk
     import gtk.glade
 
     import maindialog
+    import lockdownappliergconf
     import config
 
     try:
@@ -39,7 +42,10 @@ def main (args):
     gtk.glade.bindtextdomain (config.PACKAGE, config.LOCALEDIR)
 
     gtk.window_set_default_icon_name ("stock_lock")
-    dialog = maindialog.PessulusMainDialog ()
+
+    applier = lockdownappliergconf.PessulusLockdownApplierGconf ()
+
+    dialog = maindialog.PessulusMainDialog (applier)
 
     gtk.main ()
 
